<?php
namespace Ak\Fs\Image;

use Ak\Image\Processor\ProcessorInterface;
use Interop\Container\ContainerInterface;
use League\Flysystem\AdapterInterface;
use Laminas\ServiceManager\Exception\ServiceNotCreatedException;
use Laminas\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu Image adaptera.
 *
 * @package Ak\Fs\Image\Adapter
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/image
 */
final class ImageAdapterFactory implements FactoryInterface
{
    /**
     * Stvara adapter.
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return AdapterInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $config = $options ?? ['root' => ''];
        $processor = $config['processor'] ?? 'image_processor';

        if (is_string($processor)) {
            if (!$container->has($processor)) {
                throw new ServiceNotCreatedException(sprintf(
                    "Image procesor s imenom '%s' ne postoji u containeru.", $processor
                ));
            }

            $processor = $container->get($processor);
        }

        if (!$processor instanceof ProcessorInterface) {
            throw new ServiceNotCreatedException(sprintf(
                "Image procesor mora biti klase \Ak\Image\ProcessorInterface, a zadan je '%s'",
                is_object($processor) ? get_class($processor) : gettype($processor)
            ));
        }

        return new ImageAdapter($config['root'] ?? '', $processor);
    }
}
