<?php
namespace Ak\Fs\Image;

use Ak\Image\Processor\ResizeMode;

/**
 * Putanja slike.
 *
 * @package Ak\Fs\Image
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/fs-image
 */
final class ImagePath
{
    /** @var string */
    private $origPath;
    /** @var bool */
    private $parsed = false;
    /** @var null|ResizeMode */
    private $resizeMode;
    /** @var null|int */
    private $width;
    /** @var null|int */
    private $height;
    /** @var string */
    private $path;

    /**
     * Konstruktor.
     *
     * @param string $path
     */
    public function __construct(string $path)
    {
        $this->origPath = $path;
    }

    /**
     * Iz originalne putanje izvlači parametre slike.
     */
    private function parse(): void
    {
        if ($this->parsed === true) {
            return;
        }

        if (preg_match('/^((thumb|fit)\/)?((\d*)x(\d*)\/)?(.+)$/', $this->origPath, $matches)) {
            $this->resizeMode = $matches[2] ? new ResizeMode($matches[2]) : null;
            $this->width = $matches[4] ? intval($matches[4]) : null;
            $this->height = $matches[5] ? intval($matches[5]) : null;
            $this->path = $matches[6];

            if ($this->resizeMode === null) {
                if ($this->width === null || $this->height === null) {
                    $this->resizeMode = new ResizeMode(ResizeMode::SCALE);
                } else {
                    $this->resizeMode = new ResizeMode(ResizeMode::THUMB);
                }
            }
        }

        $this->parsed = true;
    }

    /**
     * @return ResizeMode
     */
    public function getResizeMode(): ?ResizeMode
    {
        $this->parse();
        return $this->resizeMode;
    }

    /**
     * @return int|null
     */
    public function getWidth(): ?int
    {
        $this->parse();
        return $this->width;
    }

    /**
     * @return int|null
     */
    public function getHeight(): ?int
    {
        $this->parse();
        return $this->height;
    }

    /**
     * @return string
     */
    public function getPath(): string
    {
        $this->parse();
        return $this->path;
    }

    /**
     * @return string
     */
    public function getOptimizedPath(): string
    {
        return sprintf('optimized/%s', $this->getPath());
    }

    /**
     * @return string
     */
    public function getRawPath(): string
    {
        return sprintf('raw/%s', $this->getPath());
    }

    /**
     * @return string
     */
    public function getResizedPath(): string
    {
        return ltrim(sprintf(
            '%s/%sx%s/%s',
            $this->getResizeMode(),
            $this->getWidth(),
            $this->getHeight(),
            $this->getPath()
        ), '/');
    }
}
