<?php
namespace AkTest\Fs\Image;

use Ak\Fs\Image\ImagePath;
use Ak\Image\Processor\ResizeMode;
use Ak\Test\AbstractTestCase;

/**
 * Class ImagePathTest
 *
 * @package Ak\Fs\Image
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/image
 */
final class ImagePathTest extends AbstractTestCase
{
    public function testWillDetectResizeMode()
    {
        $path = new ImagePath('thumb/some-image.jpg');
        $this->assertEquals('thumb', $path->getResizeMode());

        $path = new ImagePath('fit/some-image.jpg');
        $this->assertEquals('fit', $path->getResizeMode());

        $path = new ImagePath('some-image.jpg');
        $this->assertNull($path->getResizeMode());
    }

    public function testWillDetectDimensions()
    {
        $path = new ImagePath('thumb/43x45/some-image.jpg');
        $this->assertEquals(43, $path->getWidth());
        $this->assertEquals(45, $path->getHeight());

        $path = new ImagePath('fit/65x/some-image.jpg');
        $this->assertEquals(65, $path->getWidth());
        $this->assertNull($path->getHeight());

        $path = new ImagePath('x76/some-image.jpg');
        $this->assertNull($path->getWidth());
        $this->assertEquals(76, $path->getHeight());
        $this->assertEquals(ResizeMode::SCALE, $path->getResizeMode());

        $path = new ImagePath('some-image.jpg');
        $this->assertNull($path->getWidth());
        $this->assertNull($path->getHeight());
    }

    public function testWillDetectPath()
    {
        $path = new ImagePath('thumb/54x45/dir/subdir/some-image.jpg');
        $this->assertEquals('dir/subdir/some-image.jpg', $path->getPath());

        $path = new ImagePath('dir/subdir/some-image.jpg');
        $this->assertEquals('dir/subdir/some-image.jpg', $path->getPath());
    }

    public function testCanGetOptimizedPath()
    {
        $path = new ImagePath('subdir/some-image.jpg');
        $this->assertEquals('optimized/subdir/some-image.jpg', $path->getOptimizedPath());
    }

    public function testCanGetRawPath()
    {
        $path = new ImagePath('subdir/some-image.jpg');
        $this->assertEquals('raw/subdir/some-image.jpg', $path->getRawPath());
    }

    public function testCanGetResizedPath()
    {
        $path = new ImagePath('200x/subdir/some-image.jpg');
        $this->assertEquals('scale/200x/subdir/some-image.jpg', $path->getResizedPath());
    }
}